======
exOral
======

Eine Django-App für die Katalogisierung mündlicher Prüfungen.

Installation
------------

1. Füge ``exoral`` zu deinen ``INSTALLED_APPS`` hinzu.

2. Erzeuge die Models mittels ``python manage.py migrate``

3. Binde die URLs in die ``urls.py`` deines Projekts ein.
